@@ -27,7 +27,7 @@ class Madvr:
         self.port = port
         self.connect_timeout: int = connect_timeout
         self.logger = logger
-        self._lock = threading.Lock()
+        self._cmd_running = False
 
         # Const values
         self.MADVR_OK: Final = Connections.welcome.value
@@ -181,30 +181,28 @@ class Madvr:
 
         self.client.send(self.HEARTBEAT)
 
-        # read first 4 bytes for ok\r\n
-        ack_reply = self.client.recv(4)
+        # read all to clear buffer
+        ack_reply = self.client.recv(self.read_limit)
 
-        if ack_reply != ACKs.reply.value:
-            raise HeartBeatError(f"{ack_reply} does not match {ACKs.reply.value}")
+        if ACKs.reply.value not in ack_reply:
+            raise HeartBeatError(f"{ack_reply} did not contain {ACKs.reply.value}")
 
         # send heartbeat with notification and read ack and then regular client
         # ensure both work one after the next
         self.notification_client.send(self.HEARTBEAT)
 
-        # read first 4 bytes for ok\r\n
-        ack_reply = self.notification_client.recv(4)
+        ack_reply = self.notification_client.recv(self.read_limit)
 
-        if ack_reply != ACKs.reply.value:
-            raise HeartBeatError(f"{ack_reply} does not match {ACKs.reply.value}")
+        if ACKs.reply.value not in ack_reply:
+            raise HeartBeatError(f"{ack_reply} did not contain {ACKs.reply.value}")
 
         # send again on regular client to make sure both clients work
         self.client.send(self.HEARTBEAT)
 
-        # read first 4 bytes for ok\r\n
-        ack_reply = self.client.recv(4)
+        ack_reply = self.client.recv(self.read_limit)
 
-        if ack_reply != ACKs.reply.value:
-            raise HeartBeatError(f"{ack_reply} does not match {ACKs.reply.value}")
+        if ACKs.reply.value not in ack_reply:
+            raise HeartBeatError(f"{ack_reply} did not contain {ACKs.reply.value}")
 
         self.logger.debug("Handshakes complete")
 
@@ -268,7 +266,6 @@ class Madvr:
         command: str - command to send like KeyPress, MENU
         Raises RetryExceededError
         """
-
         # Verify the command is supported
         try:
             cmd, is_info, enum_type = self._construct_command(command)
@@ -331,7 +328,8 @@ class Madvr:
 
                     # process the output
                     return self._process_info(res, enum_type["msg"].value)
-
+                
+                self._cmd_running = False
                 return ""
 
             except socket.timeout:
@@ -379,27 +377,29 @@ class Madvr:
         """
         Poll the status for attributes and write them to state
         """
-        # If its locked, return
-        if not self._lock.acquire(blocking=False): # pylint: disable=consider-using-with
+
+        # dont run this multiple times as HA loves doing
+        if self._cmd_running:
             return
 
-        # lock so HA doesn't trip over itself
-        with self._lock:
-            try:
-                # send heartbeat so it doesnt close our connection
-                self._send_heartbeat()
-                # Get incoming signal info
-                for cmd in [
-                    "GetIncomingSignalInfo",
-                    "GetAspectRatio",
-                    "GetTemperatures",
-                    "GetOutgoingSignalInfo",
-                ]:
-                    res = self.send_command(cmd)
-                    self.logger.debug("poll_status resp: %s", res)
-                    self._process_notifications(res)
-            except (socket.timeout, socket.error, HeartBeatError) as err:
-                self.logger.error("Error getting update: %s", err)
+        try:
+            self._cmd_running = True
+            # send heartbeat so it doesnt close our connection
+            self._send_heartbeat()
+            # Get incoming signal info
+            for cmd in [
+                "GetIncomingSignalInfo",
+                "GetAspectRatio",
+                "GetTemperatures",
+                "GetOutgoingSignalInfo",
+            ]:
+                res = self.send_command(cmd)
+                self.logger.debug("poll_status resp: %s", res)
+                self._process_notifications(res)
+            self._cmd_running = False
+        except (socket.timeout, socket.error, HeartBeatError) as err:
+            self.logger.error("Error getting update: %s", err)
+            self._cmd_running = False
 
     def _process_notifications(self, input_data: Union[bytes, str]) -> None:
         """
